dnl
dnl check BloCxx
dnl
dnl LIMAL_CHECK_BLOCXX [VERSION]
dnl
AC_DEFUN([LIMAL_CHECK_BLOCXX],
[AC_REQUIRE([LIMAL_CHECK_LARGEFILE])dnl
#
# Check BloCxx installation using pkg-config (includes e.g. check for pcre)
#
m4_ifvaln([$1], [PKG_CHECK_MODULES(BLOCXX, [blocxx >= $1])],
                [PKG_CHECK_MODULES(BLOCXX, [blocxx])])
AC_SUBST(BLOCXX_CFLAGS)
AC_SUBST(BLOCXX_LIBS)

#
# Check BloCxx config header file
#
AC_CHECK_HEADER([blocxx/BLOCXX_config.h],,[
    AC_MSG_ERROR([Unable to find blocxx/BLOCXX_config.h])
])

#
# Check if blocxx was compiled with matching large file setting
#
AC_COMPILE_IFELSE(
    [AC_LANG_PROGRAM([[#include <blocxx/BLOCXX_config.h>]],
                     [return BLOCXX_WITH_LARGEFILE])],
    [blocxx_largefile=yes],[blocxx_largefile=no]
)
if test "$enable_largefile" != "$blocxx_largefile" ; then
    AC_MSG_ERROR([Large file support inconsistence with BloCxx detected!])
fi

]) # LIMAL_CHECK_BLOCXX

dnl
dnl check docbook
dnl
AC_DEFUN([LIMAL_CHECK_DOCBOOK],
[
# It's just rude to go over the net to build
XSLTPROC_FLAGS=--nonet
DOCBOOK_ROOT=
if test ! -f /etc/xml/catalog; then
        for i in /usr/share/sgml/docbook/stylesheet/xsl/nwalsh /usr/share/sgml/docbook/xsl-stylesheets /usr/share/xml/docbook/stylesheet/nwalsh/current;
        do
                if test -d "$i"; then
                        DOCBOOK_ROOT=$i
                fi
        done

        # Last resort - try net
        if test -z "$DOCBOOK_ROOT"; then
                XSLTPROC_FLAGS=
        fi
else
        XML_CATALOG=/etc/xml/catalog
        CAT_ENTRY_START='<!--'
        CAT_ENTRY_END='-->'
fi

AC_PATH_PROG(XSLTPROC,xsltproc)
XSLTPROC_WORKS=no
if test -n "$XSLTPROC"; then
        AC_MSG_CHECKING([whether xsltproc works])

        if test -n "$XML_CATALOG"; then
                DB_FILE="http://docbook.sourceforge.net/release/xsl/current/xhtml/docbook.xsl"
        else
                DB_FILE="$DOCBOOK_ROOT/docbook.xsl"
        fi

        $XSLTPROC $XSLTPROC_FLAGS $DB_FILE >/dev/null 2>&1 << END
<?xml version="1.0" encoding='ISO-8859-1'?>
<!DOCTYPE book PUBLIC "-//OASIS//DTD DocBook XML V4.1.2//EN" "http://www.oasis-open.org/docbook/xml/4.1.2/docbookx.dtd">
<book id="test">
</book>
END
        if test "$?" = 0; then
                XSLTPROC_WORKS=yes
        fi
        AC_MSG_RESULT($XSLTPROC_WORKS)
else
    AC_MSG_ERROR([xsltproc required but not found])
fi
AM_CONDITIONAL(have_xsltproc, test "$XSLTPROC_WORKS" = "yes")

AC_SUBST(XML_CATALOG)
AC_SUBST(XSLTPROC_FLAGS)
AC_SUBST(DOCBOOK_ROOT)
AC_SUBST(CAT_ENTRY_START)
AC_SUBST(CAT_ENTRY_END)
]) # LIMAL_CHECK_DOCBOOK

dnl
dnl Check large file support
dnl
AC_DEFUN([LIMAL_CHECK_LARGEFILE],
[AC_REQUIRE([AC_SYS_LARGEFILE])dnl

LFS_CPPFLAGS=""
if test "$enable_largefile" != no ; then
    enable_largefile=yes

    if test "$ac_cv_sys_file_offset_bits" != no; then
	LFS_CPPFLAGS="-D_FILE_OFFSET_BITS=$ac_cv_sys_file_offset_bits"
    fi
    if test "$ac_cv_sys_large_files" != no; then
	if test "x$LFS_CPPFLAGS" == "x" ; then
	    LFS_CPPFLAGS="-D_LARGE_FILES=$ac_cv_sys_large_files"
	else
	    LFS_CPPFLAGS="-D_LARGE_FILES=$ac_cv_sys_large_files $LFS_CPPFLAGS"
	fi
    fi
fi
AC_SUBST(LFS_CPPFLAGS)
]) # LIMAL_CHECK_LARGEFILE

dnl
dnl check LiMaL core lib
dnl
dnl LIMAL_CHECK_LIMAL [VERSION]
dnl
AC_DEFUN([LIMAL_CHECK_LIMAL],
[m4_ifvaln([$1], [PKG_CHECK_MODULES(LIMAL, [limal >= $1])],
                 [PKG_CHECK_MODULES(LIMAL, [limal])])
AC_SUBST(LIMAL_CFLAGS)
AC_SUBST(LIMAL_LIBS)

#
# Check LiMaL config header file
#
AC_CHECK_HEADER([limal/config.h],,[
    AC_MSG_ERROR([Unable to find limal/config.h])
])

]) # LIMAL_CHECK_LIMAL

dnl
dnl Check Perl
dnl
AC_DEFUN([LIMAL_CHECK_PERL],
[
##
## Check if perl is avaliable
##
AC_PROGRAM_PATH(PERL, perl)
if test -z "$PERL" ; then
    AC_MSG_ERROR([perl is missing; please install perl 5.x or later.])
fi
AC_SUBST(PERL)

##
## Find out what compiler/linker flags
## an embedded Perl interpreter needs
##
PERL_CFLAGS=`$PERL -MExtUtils::Embed -e ccopts`
PERL_LDFLAGS=`$PERL -MExtUtils::Embed -e ldopts`
AC_SUBST(PERL_CFLAGS)
AC_SUBST(PERL_LDFLAGS)

##
## Where to install modules
##
PERL_VENDORARCH=`$PERL -V:vendorarch | sed "s!.*='!!;s!'.*!!"`
AC_SUBST(PERL_VENDORARCH)
]) # LIMAL_CHECK_PERL


dnl
dnl Run given perl code
dnl
dnl LIMAL_PERL_IFELSE(PROGRAM, [ACTION-IF-TRUE], [ACTION-IF-FALSE])
dnl
AC_DEFUN([LIMAL_PERL_IFELSE],
[m4_ifvaln([$1], [AC_REQUIRE([LIMAL_CHECK_PERL])dnl
cat >conftest.pl <<_PERL_IFELSE_ACEOF
$1;
_PERL_IFELSE_ACEOF
AS_IF([AC_TRY_COMMAND([$PERL conftest.pl])],[$2],[$3])
rm -f conftest.pl])dnl
]) # LIMAL_PERL_IFELSE


dnl
dnl Check perl module avaliability
dnl
dnl LIMAL_CHECK_PERL_MODULE(MODULE, [ACTION-IF-TRUE], [ACTION-IF-FALSE])
dnl
AC_DEFUN([LIMAL_CHECK_PERL_MODULE],
[AS_VAR_PUSHDEF([limal_perl_module], [limal_perl_module_$1])dnl
AC_CACHE_CHECK([for perl module $1], limal_perl_module,
    [LIMAL_PERL_IFELSE([use $1],
        [AS_VAR_SET(limal_perl_module, yes)],
        [AS_VAR_SET(limal_perl_module, no)])
    ])
AS_IF([test AS_VAR_GET(limal_perl_module) = yes], [$2], [$3])[]dnl
AS_VAR_POPDEF([limal_perl_module])dnl
])# LIMAL_CHECK_PERL_MODULE


dnl 
dnl @synopsis LIMAL_PREFIX_CONFIG_H [(OUTPUT-HEADER [,PREFIX [,ORIG-HEADER]])]
dnl
dnl !! MODIFIED !!
dnl This is a modified version of AX_PREFIX_CONFIG_H to avoid prefixing of
dnl lowecase names (e.g. const); The changes are marked with a CHANGED tag.
dnl
dnl @synopsis AX_PREFIX_CONFIG_H [(OUTPUT-HEADER [,PREFIX [,ORIG-HEADER]])]
dnl
dnl This is a new variant from ac_prefix_config_ this one will use a
dnl lowercase-prefix if the config-define was starting with a
dnl lowercase-char, e.g. "#define const", "#define restrict", or
dnl "#define off_t", (and this one can live in another directory, e.g.
dnl testpkg/config.h therefore I decided to move the output-header to
dnl be the first arg)
dnl
dnl takes the usual config.h generated header file; looks for each of
dnl the generated "#define SOMEDEF" lines, and prefixes the defined
dnl name (ie. makes it "#define PREFIX_SOMEDEF". The result is written
dnl to the output config.header file. The PREFIX is converted to
dnl uppercase for the conversions.
dnl
dnl Defaults:
dnl
dnl   OUTPUT-HEADER = $PACKAGE-config.h
dnl   PREFIX = $PACKAGE
dnl   ORIG-HEADER, from AM_CONFIG_HEADER(config.h)
dnl
dnl Your configure.ac script should contain both macros in this order,
dnl and unlike the earlier variations of this prefix-macro it is okay
dnl to place the AX_PREFIX_CONFIG_H call before the AC_OUTPUT
dnl invokation.
dnl
dnl Example:
dnl
dnl   AC_INIT(config.h.in)        # config.h.in as created by "autoheader"
dnl   AM_INIT_AUTOMAKE(testpkg, 0.1.1)    # makes #undef VERSION and PACKAGE
dnl   AM_CONFIG_HEADER(config.h)          # prep config.h from config.h.in
dnl   AX_PREFIX_CONFIG_H(mylib/_config.h) # prep mylib/_config.h from it..
dnl   AC_MEMORY_H                         # makes "#undef NEED_MEMORY_H"
dnl   AC_C_CONST_H                        # makes "#undef const"
dnl   AC_OUTPUT(Makefile)                 # creates the "config.h" now
dnl                                       # and also mylib/_config.h
dnl
dnl if the argument to AX_PREFIX_CONFIG_H would have been omitted then
dnl the default outputfile would have been called simply
dnl "testpkg-config.h", but even under the name "mylib/_config.h" it
dnl contains prefix-defines like
dnl
dnl   #ifndef TESTPKG_VERSION
dnl   #define TESTPKG_VERSION "0.1.1"
dnl   #endif
dnl   #ifndef TESTPKG_NEED_MEMORY_H
dnl   #define TESTPKG_NEED_MEMORY_H 1
dnl   #endif
dnl   #ifndef _testpkg_const
dnl   #define _testpkg_const _const
dnl   #endif
dnl
dnl and this "mylib/_config.h" can be installed along with other
dnl header-files, which is most convenient when creating a shared
dnl library (that has some headers) where some functionality is
dnl dependent on the OS-features detected at compile-time. No need to
dnl invent some "mylib-confdefs.h.in" manually. :-)
dnl
dnl <CHANGED>
dnl
dnl Note that some AC_DEFINEs that end up in the config.h file are
dnl actually self-referential - e.g. AC_C_INLINE, AC_C_CONST, and the
dnl AC_TYPE_OFF_T say that they "will define inline|const|off_t if the
dnl system does not do it by itself". You might want to clean up about
dnl these - consider an extra mylib/conf.h that reads something like:
dnl
dnl    #include <mylib/_config.h>
dnl    #ifndef _testpkg_const
dnl    #define _testpkg_const const
dnl    #endif
dnl
dnl and then start using _testpkg_const in the header files. That is
dnl also a good thing to differentiate whether some library-user has
dnl starting to take up with a different compiler, so perhaps it could
dnl read something like this:
dnl
dnl   #ifdef _MSC_VER
dnl   #include <mylib/_msvc.h>
dnl   #else
dnl   #include <mylib/_config.h>
dnl   #endif
dnl   #ifndef _testpkg_const
dnl   #define _testpkg_const const
dnl   #endif
dnl </CHANGED>
dnl
dnl @category Misc
dnl @author Guido Draheim <guidod@gmx.de>
dnl @version 2003-11-04
dnl @license GPLWithACException
dnl
AC_DEFUN([LIMAL_PREFIX_CONFIG_H],[AC_REQUIRE([AC_CONFIG_HEADER])
AC_CONFIG_COMMANDS([ifelse($1,,$PACKAGE-config.h,$1)],[dnl
AS_VAR_PUSHDEF([_OUT],[ac_prefix_conf_OUT])dnl
AS_VAR_PUSHDEF([_DEF],[ac_prefix_conf_DEF])dnl
AS_VAR_PUSHDEF([_PKG],[ac_prefix_conf_PKG])dnl
AS_VAR_PUSHDEF([_LOW],[ac_prefix_conf_LOW])dnl
AS_VAR_PUSHDEF([_UPP],[ac_prefix_conf_UPP])dnl
AS_VAR_PUSHDEF([_INP],[ac_prefix_conf_INP])dnl
m4_pushdef([_script],[conftest.prefix])dnl
m4_pushdef([_symbol],[m4_cr_Letters[]m4_cr_digits[]_])dnl
_OUT=`echo ifelse($1, , $PACKAGE-config.h, $1)`
_DEF=`echo _$_OUT | sed -e "y:m4_cr_letters:m4_cr_LETTERS[]:" -e "s/@<:@^m4_cr_Letters@:>@/_/g"`
_PKG=`echo ifelse($2, , $PACKAGE, $2)`
_LOW=`echo _$_PKG | sed -e "y:m4_cr_LETTERS-:m4_cr_letters[]_:"`
_UPP=`echo $_PKG | sed -e "y:m4_cr_letters-:m4_cr_LETTERS[]_:"  -e "/^@<:@m4_cr_digits@:>@/s/^/_/"`
_INP=`echo "ifelse($3,,,$3)" | sed -e 's/ *//'`
if test ".$_INP" = "."; then
   for ac_file in : $CONFIG_HEADERS; do test "_$ac_file" = _: && continue
     case "$ac_file" in
        *.h) _INP=$ac_file ;;
        *)
     esac
     test ".$_INP" != "." && break
   done
fi
if test ".$_INP" = "."; then
   case "$_OUT" in
      */*) _INP=`basename "$_OUT"`
      ;;
      *-*) _INP=`echo "$_OUT" | sed -e "s/@<:@_symbol@:>@*-//"`
      ;;
      *) _INP=config.h
      ;;
   esac
fi
if test -z "$_PKG" ; then
   AC_MSG_ERROR([no prefix for _PREFIX_PKG_CONFIG_H])
else
  if test ! -f "$_INP" ; then if test -f "$srcdir/$_INP" ; then
     _INP="$srcdir/$_INP"
  fi fi
  AC_MSG_NOTICE(creating $_OUT - prefix $_UPP for $_INP defines)
  if test -f $_INP ; then
    echo "s/@%:@undef  *\\(@<:@m4_cr_LETTERS[]_@:>@\\)/@%:@undef $_UPP""_\\1/" > _script
    # CHANGED: do not add any prefix on lower case names
    # echo "s/@%:@undef  *\\(@<:@m4_cr_letters@:>@\\)/@%:@undef $_LOW""_\\1/" >> _script
    echo "s/@%:@undef  *\\(@<:@m4_cr_letters@:>@\\)/@%:@undef \\1/" >> _script
    echo "s/@%:@def[]ine  *\\(@<:@m4_cr_LETTERS[]_@:>@@<:@_symbol@:>@*\\)\\(.*\\)/@%:@ifndef $_UPP""_\\1 \\" >> _script
    # CHANGED: avoid adding space char behind the name
    #echo "@%:@def[]ine $_UPP""_\\1 \\2 \\" >> _script
    echo "@%:@def[]ine $_UPP""_\\1\\2 \\" >> _script
    echo "@%:@endif/" >>_script
    # CHANGED: do not add any prefix on lower case names
    #          and avoid adding space char behind the name
    # echo "s/@%:@def[]ine  *\\(@<:@m4_cr_letters@:>@@<:@_symbol@:>@*\\)\\(.*\\)/@%:@ifndef $_LOW""_\\1 \\" >> _script
    # echo "@%:@define $_LOW""_\\1 \\2 \\" >> _script
    echo "s/@%:@def[]ine  *\\(@<:@m4_cr_letters@:>@@<:@_symbol@:>@*\\)\\(.*\\)/@%:@ifndef \\1 \\" >> _script
    echo "@%:@define \\1\\2 \\" >> _script
    echo "@%:@endif/" >> _script
    # now executing _script on _DEF input to create _OUT output file
    echo "@%:@ifndef $_DEF"      >$tmp/pconfig.h
    echo "@%:@def[]ine $_DEF 1" >>$tmp/pconfig.h
    echo ' ' >>$tmp/pconfig.h
    echo /'*' $_OUT. Generated automatically at end of configure. '*'/ >>$tmp/pconfig.h

    sed -f _script $_INP >>$tmp/pconfig.h
    echo ' ' >>$tmp/pconfig.h
    echo '/* once:' $_DEF '*/' >>$tmp/pconfig.h
    echo "@%:@endif" >>$tmp/pconfig.h
    if cmp -s $_OUT $tmp/pconfig.h 2>/dev/null; then
      AC_MSG_NOTICE([$_OUT is unchanged])
    else
      ac_dir=`AS_DIRNAME(["$_OUT"])`
      AS_MKDIR_P(["$ac_dir"])
      rm -f "$_OUT"
      mv $tmp/pconfig.h "$_OUT"
    fi
    cp _script _configs.sed
  else
    AC_MSG_ERROR([input file $_INP does not exist - skip generating $_OUT])
  fi
  rm -f conftest.*
fi
m4_popdef([_symbol])dnl
m4_popdef([_script])dnl
AS_VAR_POPDEF([_INP])dnl
AS_VAR_POPDEF([_UPP])dnl
AS_VAR_POPDEF([_LOW])dnl
AS_VAR_POPDEF([_PKG])dnl
AS_VAR_POPDEF([_DEF])dnl
AS_VAR_POPDEF([_OUT])dnl
],[PACKAGE="$PACKAGE"])])

dnl
dnl check swig
dnl
AC_DEFUN([LIMAL_CHECK_SWIG],
[
# check swig path
AC_PATH_PROG(SWIG, swig)

if test -n "$SWIG"; then
    AC_MSG_CHECKING([evaluate path of swiglib])
    SWIG_LIB=$limaldatadir/typemaps/
    AC_MSG_RESULT($SWIG_LIB)
else
    AC_MSG_ERROR([swig required but not found])
fi
AC_SUBST(SWIG_LIB)
])

