/*---------------------------------------------------------------------\
|                                                                      |
|                     _     _   _   _     __     _                     |
|                    | |   | | | \_/ |   /  \   | |                    |
|                    | |   | | | |_| |  / /\ \  | |                    |
|                    | |__ | | | | | | / ____ \ | |__                  |
|                    |____||_| |_| |_|/ /    \ \|____|                 |
|                                                                      |
|                             XXpkgXX library                          |
|                                                                      |
|                                         (C) SUSE Linux Products GmbH |
\----------------------------------------------------------------------/

  File:       Utils.hpp

  Author:     XXmaintainerXX <XXemailXX>
  Maintainer: XXmaintainerXX <XXemailXX>

/-*/
/**
 * @file   Utils.hpp
 * @brief  This file is private for the XXpkgXX library.
 *         It defines common utilities e.g. a logger macro
 *         and a gettext text domain and a helper macro
 *         for internationalization.
 */
#ifndef  UTILS_HPP
#define  UTILS_HPP
#include <limal/XXpkgXX/config.h>
#include <limal/Logger.hpp>


// -------------------------------------------------------------------
/**
 * Logging helper macro for the XXpkgXX library.
 */
#define LOGIT(level,message)    \
        LIMAL_SLOG(limal::Logger("XXpkgXX"), level, message)


// -------------------------------------------------------------------
/**
 * Text domain for the XXpkgXX library.
 */
#define i18n_domain	"limal-XXpkgXX"


// -------------------------------------------------------------------
/**
 * Internationalization helper macro.
 */
#define __(MSG)  limal::XXpKgXX::gettext( MSG )


// -------------------------------------------------------------------
namespace LIMAL_NAMESPACE
{
namespace XXPKGXX_NAMESPACE
{

// -------------------------------------------------------------------
/**
 * @{
 * Internationalization gettext-wrapper functions.
 * This functions initialize the text domain 'i18n_domain'
 * once and finally forward the calls to the d*gettext
 * functions using 'i18n_domain' as text domain.
 *
 * @param msgid  The singular message to be translated.
 * @param plural The plural message to be translated.
 * @param n      The number of the plural message.
 * @return The translated message or msgid.
 */
const char *       gettext (const char *msgid);
const char *       gettext (const char *msgid,
                            const char *plural,
                            unsigned long int n);
/* @} */


// -------------------------------------------------------------------
}       // End of XXPKGXX_NAMESPACE
}       // End of LIMAL_NAMESPACE
#endif  // UTILS_HPP
// vim: set ts=8 sts=8 sw=8 ai noet:
